==> openstory-8.x-2.4.tar.gz: openstory/src/Plugin/rest/resource/CountStories.php <==
<?php

namespace Drupal\openstory\Plugin\rest\resource;

use Drupal\rest\Plugin\ResourceBase;
use Drupal\rest\ResourceResponse;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Psr\Log\LoggerInterface;

/**
 * Provides a resource to count stories.
 *
 * @RestResource(
 *   id = "get_count_stories",
 *   label = @Translation("Count stories"),
 *   uri_paths = {
 *     "canonical" = "/get_count_stories/{days}"
 *   }
 * )
 */
class CountStories extends ResourceBase {

  /**
   * A current user instance.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a Drupal\rest\Plugin\ResourceBase object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param array $serializer_formats
   *   The available serialization formats.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   *   A current user instance.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, array $serializer_formats, LoggerInterface $logger, AccountProxyInterface $current_user, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer_formats, $logger);
    $this->currentUser = $current_user;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->getParameter('serializer.formats'),
      $container->get('logger.factory')->get('custom_rest'),
      $container->get('current_user'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * Count all nodes of a content type.
   *
   * @param string $days
   *   Filter on x days.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\HttpException
   *   Throws exception expected.
   *
   * @return \Drupal\rest\ResourceResponse
   *   The HTTP response object.
   */
  public function get($days) {
    // Get stories from current date - $days days.
    $date = strtotime("-" . $days . " days");
    $query = $this->entityTypeManager->getStorage('node')->getAggregateQuery();
    $query->condition('created', $date, '>');
    $query->aggregate("type", 'COUNT');
    $query->groupBy("type");
    $result = $query->execute();
    $storiesFirstPeriod = $this->createBundleArray($result);
    arsort($storiesFirstPeriod);

    // Get stories from current date - $days * 2 days in order to see
    // if the number of nodes of a content type increased or decreased.
    $date = strtotime("-" . $days * 2 . " days");
    $query1 = $this->entityTypeManager->getStorage('node')->getAggregateQuery();
    $query1->condition('created', $date, '>');
    $query1->aggregate("type", 'COUNT');
    $query1->groupBy("type");
    $result1 = $query1->execute();
    $storiesSecondPeriod = $this->createBundleArray($result1);
    arsort($storiesSecondPeriod);

    // Get all stories from current date - $days days.
    $date = strtotime("-" . $days . " days");
    $query = $this->entityTypeManager->getStorage('node')->getAggregateQuery();
    $query->condition('created', $date, '>');
    $query->aggregate("type", 'COUNT');
    $result = $query->execute();
    $allStories = $result[0]['type_count'];

    $stories = [];
    $stories['All Stories'] = ['all_stories' => $allStories];
    $other = 0;
    $i = 0;
    foreach ($storiesFirstPeriod as $bundle => $story) {
      if (++$i > 5) {
        break;
      }
      if (array_key_exists($bundle, $storiesSecondPeriod)) {
        // Get the count for the second period.
        // The second period contains also the stories from first period.
        $count = $storiesSecondPeriod[$bundle] - $story;
        if ($count === 0) {
          $stories[$bundle] = ['count' => $story, 'arrow' => 'none'];
        }
        elseif ($story > $count) {
          $stories[$bundle] = ['count' => $story, 'arrow' => 'greater'];
        }
        elseif ($story < $count) {
          $stories[$bundle] = ['count' => $story, 'arrow' => 'smaller'];
        }
        else {
          $stories[$bundle] = ['count' => $story, 'arrow' => 'smaller'];
        }
      }
      else {
        $stories[$bundle] = ['count' => $story, 'arrow' => 'none'];
      }
      $other += $story;
    }

    $stories['Other'] = ['other' => $allStories - $other];
    $response = new ResourceResponse($stories, 200);
    return $response;

  }

  /**
   * Create array from query entity result.
   *
   * @param array $queryArray
   *   Array result from entity query.
   *
   * @return array
   *   Return array.
   */
  private function createBundleArray(array $queryArray) {
    $result = [];
    if (!empty($queryArray)) {
      foreach ($queryArray as $item => $content) {
        if (!empty($content)) {
          $result[$content['type']] = $content['type_count'];
        }
      }
    }
    return $result;
  }

}

==> openstory-8.x-2.12.tar.gz: openstory/src/Plugin/rest/resource/CountStories.php <==
<?php

namespace Drupal\openstory\Plugin\rest\resource;

use Drupal\rest\Plugin\ResourceBase;
use Drupal\rest\ResourceResponse;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Psr\Log\LoggerInterface;

/**
 * Provides a resource to count stories.
 *
 * @RestResource(
 *   id = "get_count_stories",
 *   label = @Translation("Count stories"),
 *   uri_paths = {
 *     "canonical" = "/get_count_stories/{days}"
 *   }
 * )
 */
class CountStories extends ResourceBase {

  /**
   * A current user instance.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a Drupal\rest\Plugin\ResourceBase object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param array $serializer_formats
   *   The available serialization formats.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   *   A current user instance.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, array $serializer_formats, LoggerInterface $logger, AccountProxyInterface $current_user, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer_formats, $logger);
    $this->currentUser = $current_user;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->getParameter('serializer.formats'),
      $container->get('logger.factory')->get('custom_rest'),
      $container->get('current_user'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * Count all nodes of a content type.
   *
   * @param string $days
   *   Filter on x days.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\HttpException
   *   Throws exception expected.
   *
   * @return \Drupal\rest\ResourceResponse
   *   The HTTP response object.
   */
  public function get($days) {
    // Get stories from current date - $days days.
    $date = strtotime("-" . $days . " days");
    $query = $this->entityTypeManager->getStorage('node')->getAggregateQuery();
    $query->condition('created', $date, '>');
    $query->aggregate("type", 'COUNT');
    $query->groupBy("type");
    $result = $query->execute();
    $storiesFirstPeriod = $this->createBundleArray($result);
    arsort($storiesFirstPeriod);

    // Get stories from current date - $days * 2 days in order to see
    // if the number of nodes of a content type increased or decreased.
    $date = strtotime("-" . $days * 2 . " days");
    $query1 = $this->entityTypeManager->getStorage('node')->getAggregateQuery();
    $query1->condition('created', $date, '>');
    $query1->aggregate("type", 'COUNT');
    $query1->groupBy("type");
    $result1 = $query1->execute();
    $storiesSecondPeriod = $this->createBundleArray($result1);
    arsort($storiesSecondPeriod);

    // Get all stories from current date - $days days.
    $date = strtotime("-" . $days . " days");
    $query = $this->entityTypeManager->getStorage('node')->getAggregateQuery();
    $query->condition('created', $date, '>');
    $query->aggregate("type", 'COUNT');
    $result = $query->execute();
    $allStories = $result[0]['type_count'];

    $stories = [];
    $stories['All Stories'] = ['all_stories' => (int) $allStories];
    $other = 0;
    $i = 0;
    foreach ($storiesFirstPeriod as $bundle => $story) {
      if (++$i > 5) {
        break;
      }
      if (array_key_exists($bundle, $storiesSecondPeriod)) {
        // Get the count for the second period.
        // The second period contains also the stories from first period.
        $count = $storiesSecondPeriod[$bundle] - $story;
        if ($count === 0) {
          $stories[$bundle] = ['count' => $story, 'arrow' => 'none'];
        }
        elseif ($story > $count) {
          $stories[$bundle] = ['count' => $story, 'arrow' => 'greater'];
        }
        elseif ($story < $count) {
          $stories[$bundle] = ['count' => $story, 'arrow' => 'smaller'];
        }
        else {
          $stories[$bundle] = ['count' => $story, 'arrow' => 'smaller'];
        }
      }
      else {
        $stories[$bundle] = ['count' => $story, 'arrow' => 'none'];
      }
      $other += $story;
    }

    if (count($stories) < 6) {
      $storiesCount = count($stories);
      $bundles = $this->entityTypeManager->getStorage('node_type')->loadMultiple();
      if (!empty($bundles)) {
        $i = 0;
        foreach ($bundles as $bundle => $bundleValue) {
          if ($i < 6 - $storiesCount) {
            $bundleName = $node_type = $this->entityTypeManager->getStorage('node_type')->load($bundle)->get('name');
            $stories[$bundleName] = ['count' => 0, 'arrow' => 'none'];
            $i++;
          }
          else {
            break;
          }
        }
      }
    }
    $stories['Other'] = ['other' => $allStories - $other];
    $response = new ResourceResponse($stories, 200);
    return $response;

  }

  /**
   * Create array from query entity result.
   *
   * @param array $queryArray
   *   Array result from entity query.
   *
   * @return array
   *   Return array.
   */
  private function createBundleArray(array $queryArray) {
    $result = [];
    if (!empty($queryArray)) {
      foreach ($queryArray as $item => $content) {
        if (!empty($content)) {
          $result[$content['type']] = $content['type_count'];
        }
      }
    }
    return $result;
  }

}
